@@ -60,7 +60,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName ACRO_FORM = new COSName( "AcroForm" );
     /**
-     * "ActualText"
+     * A common COSName value.
      */
     public static final COSName ACTUAL_TEXT = new COSName("ActualText");
     /**
@@ -68,11 +68,11 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName AIS = new COSName( "AIS" );
     /**
-     * "Alt"
+     * A common COSName value.
      */
     public static final COSName ALT = new COSName("Alt");
     /**
-     * "Alt"
+     * A common COSName value.
      */
     public static final COSName ALTERNATE = new COSName("Alternate");
     /**
@@ -92,7 +92,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName AP_REF = new COSName( "APRef" );
     /**
-     * "Artifact"
+     * A common COSName value.
      */
     public static final COSName ARTIFACT = new COSName("Artifact");
     /**
@@ -112,7 +112,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName ASCII85_DECODE_ABBREVIATION = new COSName( "A85" );
     /**
-     * "Attached"
+     * A common COSName value.
      */
     public static final COSName ATTACHED = new COSName("Attached");
     /**
@@ -128,7 +128,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName ASCII_HEX_DECODE_ABBREVIATION = new COSName( "AHx" );
 
-    /** "AP" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName AP = new COSName( "AP" );
 
     /**
@@ -148,6 +150,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
     /**
     * A common COSName value.
     */
+    public static final COSName BACKGROUND = new COSName( "Background" );
+    /**
+    * A common COSName value.
+    */
     public static final COSName BASE_ENCODING = new COSName( "BaseEncoding" );
     /**
     * A common COSName value.
@@ -178,6 +184,14 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName BITS_PER_COMPONENT = new COSName("BitsPerComponent" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName BITS_PER_COORDINATE = new COSName("BitsPerCoordinate" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName BITS_PER_FLAG = new COSName("BitsPerFlag" );
     /**
      * A common COSName value.
      */
@@ -195,7 +209,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName CATALOG = new COSName( "Catalog" );
     /**
-     * "C"
+     * A common COSName value.
      */
     public static final COSName C = new COSName("C");
     /**
@@ -234,6 +248,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
     * A common COSName value.
     */
     public static final COSName CCITTFAX_DECODE_ABBREVIATION = new COSName( "CCF" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName CENTER_WINDOW = new COSName( "CenterWindow" );
     /**
      * A common COSName value.
      */
@@ -262,6 +280,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
     * A common COSName value.
     */
     public static final COSName CIDSYSTEMINFO = new COSName( "CIDSystemInfo" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName CID_TO_GID_MAP = new COSName( "CIDToGIDMap" );
     /**
      * A common COSName value.
      */
@@ -311,17 +333,17 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName CROP_BOX = new COSName(  "CropBox" );
     /**
-     * The Crypt filter.
+     * A common COSName value.
      */
     public static final COSName CRYPT = new COSName( "Crypt" );
     /**
      * A common COSName value.
      */
     public static final COSName CS = new COSName(  "CS" );
-
-    /** "D" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName D = new COSName( "D" );
-
     /**
      * A common COSName value.
      */
@@ -339,7 +361,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName DECODE = new COSName( "Decode" );
-    /** "DecodeParms" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName DECODE_PARMS = new COSName( "DecodeParms" );
 
     /**
@@ -355,7 +379,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName DEST = new COSName(  "Dest" );
 
-    /** "Dests" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName DESTS = new COSName( "Dests" );
 
     /**
@@ -378,22 +404,42 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName DIFFERENCES = new COSName( "Differences" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DIRECTION = new COSName( "Direction" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DISPLAY_DOC_TITLE = new COSName( "DisplayDocTitle" );
 
-    /** "DL" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName DL = new COSName( "DL" );
+    
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DOC_CHECKSUM = new COSName( "DocChecksum" );
 
     /**
      * A common COSName value.
      */
     public static final COSName DOMAIN = new COSName( "Domain" );
-
-     /** "DP" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName DP = new COSName( "DP" );
 
     /**
      * A common COSName value.
      */
     public static final COSName DR = new COSName( "DR" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DUPLEX = new COSName( "Duplex" );
     /**
      * A common COSName value.
      */
@@ -404,13 +450,20 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName DW = new COSName( "DW" );
 
     /**
-     * "E"
+     * A common COSName value.
      */
     public static final COSName E = new COSName("E");
 
-    /** "EmbeddedFiles" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName EMBEDDED_FILES = new COSName( "EmbeddedFiles" );
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName EMBEDDED_FDFS = new COSName( "EmbeddedFDFs" );
+    
     /**
      * A common COSName value.
      */
@@ -436,13 +489,19 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName ENCODING_ETEN_B5_V = new COSName( "ETen?B5?V" );
 
-    /** "Encrypt" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName ENCRYPT = new COSName( "Encrypt" );
 
-    /** "EncryptMetaData" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName ENCRYPT_META_DATA = new COSName( "EncryptMetadata" );
     
-    /** "ExtGState" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName EXT_G_STATE = new COSName( "ExtGState" );
 
     /**
@@ -450,16 +509,24 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName EXTEND = new COSName( "Extend" );
 
-    /** "Extends" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName EXTENDS = new COSName( "Extends" );
 
-    /** "F" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName F = new COSName( "F" );
 
-    /** "FDecodeParms" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName F_DECODE_PARMS = new COSName( "FDecodeParms" );
 
-    /** "FFilter" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName F_FILTER = new COSName( "FFilter" );
 
     /**
@@ -478,6 +545,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
     * A common COSName value.
     */
     public static final COSName FIRST_CHAR = new COSName( "FirstChar" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName FIT_WINDOW = new COSName( "FitWindow" );
     /**
     * A common COSName value.
     */
@@ -578,15 +649,31 @@ public final class COSName extends COSBase implements Comparable<COSName>
     * A common COSName value.
     */
     public static final COSName HEIGHT = new COSName( "Height" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName HIDE_MENUBAR = new COSName( "HideMenubar" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName HIDE_TOOLBAR = new COSName( "HideToolbar" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName HIDE_WINDOWUI = new COSName( "HideWindowUI" );
     /**
     * A common COSName value.
     */
     public static final COSName ICCBASED = new COSName( "ICCBased" );
 
-    /** "ID" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName ID = new COSName("ID");
 
-    /** "IDTree" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName ID_TREE = new COSName("IDTree");
 
     /**
@@ -606,7 +693,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName IMAGE_MASK = new COSName( "ImageMask" );
 
-    /** "Index" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName INDEX = new COSName( "Index" );
 
     /**
@@ -622,7 +711,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName ITALIC_ANGLE = new COSName( "ItalicAngle" );
 
-    /** "JavaScript" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName JAVA_SCRIPT = new COSName( "JavaScript" );
 
     /**
@@ -634,7 +725,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName JPX_DECODE = new COSName( "JPXDecode" );
 
-    /** "K" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName K = new COSName("K");
 
     /**
@@ -642,7 +735,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName KEYWORDS = new COSName( "Keywords" );
 
-    /** "Kids" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName KIDS = new COSName( "Kids" );
 
     /**
@@ -650,13 +745,19 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName LAB = new COSName( "Lab" );
 
-    /** "Lang" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName LANG = new COSName("Lang");
 
     /**
      * A common COSName value.
      */
     public static final COSName LAST_CHAR = new COSName( "LastChar" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName LAST_MODIFIED = new COSName( "LastModified" );
     /**
      * A common COSName value.
      */
@@ -674,7 +775,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName LENGTH1 = new COSName( "Length1" );
 
-    /** "Limits" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName LIMITS = new COSName( "Limits" );
     /**
      * A common COSName value.
@@ -701,7 +804,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName MAC_ROMAN_ENCODING = new COSName( "MacRomanEncoding" );
 
-    /** "MarkInfo" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName MARK_INFO = new COSName("MarkInfo");
 
     /**
@@ -717,7 +822,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName MAX_WIDTH = new COSName( "MaxWidth" );
     /**
-     * "MCID"
+     * A common COSName value.
      */
     public static final COSName MCID = new COSName("MCID");
     /**
@@ -753,7 +858,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName NAME = new COSName( "Name" );
 
-    /** "Names" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName NAMES = new COSName( "Names" );
 
     /**
@@ -764,16 +871,21 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName NM = new COSName( "NM" );
-    /** "Nums" */
+    /**
+     * A common COSName value.
+     */
+    public static final COSName NON_FULL_SCREEN_PAGE_MODE = new COSName( "NonFullScreenPageMode" );
+    /**
+     * A common COSName value.
+     */
     public static final COSName NUMS = new COSName( "Nums" );
 
     /**
-     * "O"
+     * A common COSName value.
      */
     public static final COSName O = new COSName("O");
-
     /**
-     * "Obj"
+     * A common COSName value.
      */
     public static final COSName OBJ = new COSName("Obj");
 
@@ -812,10 +924,14 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName OPT = new COSName( "Opt" );
-    /** "Outlines" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName OUTLINES = new COSName("Outlines");
 
-    /** "OpenAction" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName OPEN_ACTION = new COSName("OpenAction");
 
     /** A common COSName value. */
@@ -834,13 +950,19 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName PAGE = new COSName( "Page" );
 
-    /** "PageLabels" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName PAGE_LABELS = new COSName("PageLabels");
 
-    /** "PageLayout" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName PAGE_LAYOUT = new COSName("PageLayout");
 
-    /** "PageMode" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName PAGE_MODE = new COSName("PageMode");
 
     /**
@@ -850,9 +972,13 @@ public final class COSName extends COSBase implements Comparable<COSName>
     /**
     * A common COSName value.
     */
+    public static final COSName PAINT_TYPE = new COSName( "PaintType" );
+    /**
+    * A common COSName value.
+    */
     public static final COSName PARENT = new COSName( "Parent" );
     /**
-     * "ParentTreeNextKey"
+     * A common COSName value.
      */
     public static final COSName PARENT_TREE_NEXT_KEY = new COSName("ParentTreeNextKey");
     /**
@@ -862,9 +988,13 @@ public final class COSName extends COSBase implements Comparable<COSName>
     /**
     * A common COSName value.
     */
+    public static final COSName PATTERN_TYPE = new COSName( "PatternType" );
+    /**
+    * A common COSName value.
+    */
     public static final COSName PDF_DOC_ENCODING = new COSName( "PDFDocEncoding" );
     /**
-     * "Pg"
+     * A common COSName value.
      */
     public static final COSName PG = new COSName("Pg");
     /**
@@ -876,6 +1006,19 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName PREV = new COSName( "Prev" );
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName PRINT_AREA = new COSName( "PrintArea" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName PRINT_CLIP = new COSName( "PrintClip" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName PRINT_SCALING = new COSName( "PrintScaling" );
+    
     /** The COSName value for "ProcSet". */
     public static final COSName PROC_SET = new COSName( "ProcSet" );
 
@@ -916,7 +1059,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     */
     public static final COSName RESOURCES = new COSName( "Resources" );
     /**
-     * "RoleMap"
+     * A common COSName value.
      */
     public static final COSName RI = new COSName( "RI" );
     /**
@@ -948,7 +1091,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName RV = new COSName( "RV" );
     /**
-     * "S"
+     * A common COSName value.
      */
     public static final COSName S = new COSName("S");
     /**
@@ -972,7 +1115,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName SET_FF = new COSName( "SetFf" );
 
-    /** "Shading" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName SHADING = new COSName( "Shading" );
     /**
      * A common COSName value.
@@ -986,13 +1131,19 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName SMASK = new COSName( "SMask" );
-    /** "Size" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName SIZE = new COSName( "Size" );
 
     /**
     * A common COSName value.
     */
     public static final COSName STANDARD_ENCODING = new COSName( "StandardEncoding" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName STATUS = new COSName( "Status" );
     /**
      * A common COSName value.
      */
@@ -1014,7 +1165,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName STR_F = new COSName( "StrF" );
 
-    /** "StructTreeRoot" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName STRUCT_TREE_ROOT = new COSName("StructTreeRoot");
 
     /**
@@ -1039,13 +1192,24 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName SUBTYPE = new COSName( "Subtype" );
 
     /**
-     * "T"
+     * A common COSName value.
      */
     public static final COSName T = new COSName("T");
 
-    /** "Threads" */
+    /**
+     * A common COSName value.
+     */
+    public static final COSName TARGET = new COSName("Target");
+
+    /**
+     * A common COSName value.
+     */
     public static final COSName THREADS = new COSName("Threads");
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName TILING_TYPE = new COSName( "TilingType" );
     /**
      * A common COSName value.
      */
@@ -1097,7 +1261,9 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName U = new COSName( "U" );
     /** the COSName for the "Unchanged" value. */
     public static final COSName UNCHANGED = new COSName("Unchanged");
-    /** "URI" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName URI = new COSName("URI");
 
     /**
@@ -1108,8 +1274,22 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName VERSION = new COSName( "Version" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName VERTICES_PER_ROW = new COSName( "VerticesPerRow" );
 
-    /** "ViewerPreferences" */
+    /**
+     * A common COSName value.
+     */
+    public static final COSName VIEW_AREA = new COSName("ViewArea");
+    /**
+     * A common COSName value.
+     */
+    public static final COSName VIEW_CLIP = new COSName("ViewClip");
+    /**
+     * A common COSName value.
+     */
     public static final COSName VIEWER_PREFERENCES = new COSName("ViewerPreferences");
 
     /**
@@ -1138,12 +1318,22 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName XHEIGHT = new COSName( "XHeight" );
 
-    /** "XObject" */
+    /**
+     * A common COSName value.
+     */
     public static final COSName XOBJECT = new COSName( "XObject" );
     /**
      * A common COSName value.
      */
     public static final COSName XREF = new COSName( "XRef" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName X_STEP = new COSName( "XStep" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName Y_STEP = new COSName( "YStep" );
     /**
      * The prefix to a PDF name.
      */
@@ -1182,7 +1372,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName ADBE_PKCS7_DETACHED = new COSName("adbe.pkcs7.detached");
     /**
-     * A signature subfilter value.www
+     * A signature subfilter value.
      */
     public static final COSName ADBE_PKCS7_SHA1 = new COSName("adbe.pkcs7.sha1");
     /**
