@@ -55,13 +55,14 @@ public class PDFStreamParser extends BaseParser
      * @since Apache PDFBox 1.3.0
      * @param stream The stream to read data from.
      * @param raf The random access file.
-     * @param forceParcing flag to skip malformed or otherwise unparseable
+     * @param forceParsing flag to skip malformed or otherwise unparseable
      *                     input where possible
      * @throws IOException If there is an error reading from the stream.
      */
     public PDFStreamParser(
             InputStream stream, RandomAccess raf, boolean forceParsing)
-            throws IOException {
+            throws IOException 
+    {
         super(stream, forceParsing);
         file = raf;
     }
@@ -75,7 +76,8 @@ public class PDFStreamParser extends BaseParser
      * @throws IOException If there is an error reading from the stream.
      */
     public PDFStreamParser(InputStream stream, RandomAccess raf)
-            throws IOException {
+            throws IOException 
+    {
         this(stream, raf, FORCE_PARSING);
     }
 
@@ -96,12 +98,13 @@ public class PDFStreamParser extends BaseParser
      *
      * @since Apache PDFBox 1.3.0
      * @param stream The stream to parse.
-     * @param forceParcing flag to skip malformed or otherwise unparseable
+     * @param forceParsing flag to skip malformed or otherwise unparseable
      *                     input where possible
      * @throws IOException If there is an error initializing the stream.
      */
     public PDFStreamParser(COSStream stream, boolean forceParsing)
-            throws IOException {
+            throws IOException 
+    {
        this(stream.getUnfilteredStream(), stream.getScratchFile(), forceParsing);
     }
 
@@ -149,66 +152,67 @@ public class PDFStreamParser extends BaseParser
     {
         return streamObjects;
     }
-    
+
+    /**
+     * {@inheritDoc}
+     */
     public void close() throws IOException
     {
-    	pdfSource.close();
+        pdfSource.close();
     }
 
     /**
      * This will get an iterator which can be used to parse the stream
      * one token after the other.
-     * 
+     *
      * @return an iterator to get one token after the other
      */
     public Iterator<Object> getTokenIterator()
     {
         return new Iterator<Object>()
         {
-			private Object	token;
-			
-			private void tryNext()
-			{
-				try {
-					if(token == null)
-					{
-						token = parseNextToken();
-					}
-				} catch (IOException e) {
-					throw new RuntimeException(e);
-				}
-			}
+            private Object token;
 
-		    /**
-		     * {@inheritDoc}
-		     */
-			public boolean hasNext() 
-			{
-				tryNext();
-				return token != null;
-			}
+            private void tryNext()
+            {
+                try
+                {
+                    if (token == null)
+                    {
+                        token = parseNextToken();
+                    }
+                }
+                catch (IOException e)
+                {
+                    throw new RuntimeException(e);
+                }
+            }
 
-		    /**
-		     * {@inheritDoc}
-		     */
-			public Object next() {
-				tryNext();
-				Object tmp = token;
-				if(tmp == null)
-				{
-					throw new NoSuchElementException();
-				}
-				token = null;
-				return tmp;
-			}
+            /** {@inheritDoc} */
+            public boolean hasNext()
+            {
+                tryNext();
+                return token != null;
+            }
 
-		    /**
-		     * {@inheritDoc}
-		     */
-			public void remove() 
-			{
-				throw new UnsupportedOperationException();
-			}
+            /** {@inheritDoc} */
+            public Object next() 
+            {
+                tryNext();
+                Object tmp = token;
+                if (tmp == null)
+                {
+                    throw new NoSuchElementException();
+                }
+                token = null;
+                return tmp;
+            }
+
+            /** {@inheritDoc} */
+            public void remove()
+            {
+                throw new UnsupportedOperationException();
+            }
         };
     }
 
@@ -461,25 +465,26 @@ public class PDFStreamParser extends BaseParser
         //average string size is around 2 and the normal string buffer size is
         //about 16 so lets save some space.
         StringBuffer buffer = new StringBuffer(4);
-        int nextChar = (int)pdfSource.peek();
+        int nextChar = pdfSource.peek();
         while(
             nextChar != -1 && // EOF
             !isWhitespace(nextChar) &&
             !isClosing(nextChar) &&
-            nextChar != (int)'[' &&
-            nextChar != (int)'<' &&
-            nextChar != (int)'(' &&
-            nextChar != (int)'/' &&
-            (nextChar < (int)'0' ||
-             nextChar > (int)'9' ) )
+            nextChar != '[' &&
+            nextChar != '<' &&
+            nextChar != '(' &&
+            nextChar != '/' &&
+            (nextChar < '0' ||
+             nextChar > '9' ) )
         {
             char currentChar = (char)pdfSource.read();
-            nextChar = (int)pdfSource.peek();
+            nextChar = pdfSource.peek();
             buffer.append( currentChar );
-            // Type3 Glyph description has operators with a number in the name 
-            if (currentChar == 'd' && (nextChar == '0' || nextChar == '1') ) {
+            // Type3 Glyph description has operators with a number in the name
+            if (currentChar == 'd' && (nextChar == '0' || nextChar == '1') ) 
+            {
                 buffer.append( (char)pdfSource.read() );
-                nextChar = (int)pdfSource.peek();
+                nextChar = pdfSource.peek();
             }
         }
         return buffer.toString();
